SkyModel Class
==============

SkyModel is the main user class. It is a container for point source and
diffuse models that can be interacted with directly and it provides import and
export functionality.

.. autoclass:: pyradiosky.SkyModel
  :members:
